==> tnnt_templates-2.5.1.tar.gz: tnnt_templates-2.5.1/tnnt_templates/static/tnnt_templates/libs/slim-select/1.26.0/README.md <==
# Slim Select
## slimselectjs.com
Slim advanced select dropdown

[![Build Status](https://travis-ci.org/brianvoe/slim-select.svg?branch=master)](https://travis-ci.org/brianvoe/slim-select)
[![NPM Downloads](https://img.shields.io/npm/dt/slim-select.svg)](https://www.npmjs.com/package/slim-select)

<a href="https://www.buymeacoffee.com/brianvoe" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>

For documentation and examples on all features see: http://slimselectjs.com

![](https://raw.githubusercontent.com/brianvoe/slim-select/master/slimselect.gif)

## Features
- No Dependencies
- 20kb - 5kb gzip
- Single Select
- Multi Select
- User Addable Options
- Html Options
- Settable Data
- Callback Events
- Placeholders
- Search
- Disable Options
- Light CSS
- Light Color Scheme
- Style and Class Inheritance
- Clean Animations
- Performant

## Browsers
- IE 11+
- Edge 13+
- Chrome 30+
- FireFox 25+
- Opera 25+
- Safari 9+

## Installation
```bash
npm install slim-select
```

### or

```html
<script src="https://cdnjs.cloudflare.com/ajax/libs/slim-select/<version>/slimselect.min.js"></script>
<link rel="stylesheet" type="text/css" href="https://cdnjs.cloudflare.com/ajax/libs/slim-select/<version>/slimselect.min.css">
```

## Usage
```javascript
import SlimSelect from 'slim-select'

new SlimSelect({
  select: '#slim-select'
})
```

## Testing
Browser testing has been provided by

<img src="https://digitalscientists.com/system/images/1448/original/logo-browserstack.png" width="300" />

==> tnnt_templates-2.8.0.tar.gz: tnnt_templates-2.8.0/tnnt_templates/static/tnnt_templates/libs/slim-select/1.26.0/README.md <==
# Slim Select
## slimselectjs.com
Slim advanced select dropdown

[![Build Status](https://travis-ci.org/brianvoe/slim-select.svg?branch=master)](https://travis-ci.org/brianvoe/slim-select)
[![NPM Downloads](https://img.shields.io/npm/dt/slim-select.svg)](https://www.npmjs.com/package/slim-select)

<a href="https://www.buymeacoffee.com/brianvoe" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>

For documentation and examples on all features see: http://slimselectjs.com

![](https://raw.githubusercontent.com/brianvoe/slim-select/master/slimselect.gif)

## Features
- No Dependencies
- 20kb - 5kb gzip
- Single Select
- Multi Select
- User Addable Options
- Html Options
- Settable Data
- Callback Events
- Placeholders
- Search
- Disable Options
- Light CSS
- Light Color Scheme
- Style and Class Inheritance
- Clean Animations
- Performant

## Browsers
- IE 11+
- Edge 13+
- Chrome 30+
- FireFox 25+
- Opera 25+
- Safari 9+

## Installation
```bash
npm install slim-select
```

### or

```html
<script src="https://cdnjs.cloudflare.com/ajax/libs/slim-select/<version>/slimselect.min.js"></script>
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/slim-select/<version>/slimselect.min.css">
```

## Usage
```javascript
import SlimSelect from 'slim-select'

new SlimSelect({
  select: '#slim-select'
})
```

## Testing
Browser testing has been provided by

<img src="https://digitalscientists.com/system/images/1448/original/logo-browserstack.png" width="300" />
